==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerRelayReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerRelay resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerRelayReference mailManagerRelayReference = MailManagerRelayReference.builder()
 *         .relayId("relayId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:04.001Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerRelayReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerRelayReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerRelayReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The RelayId of the MailManagerRelay resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRelayId();

    /**
     * @return a {@link Builder} of {@link MailManagerRelayReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerRelayReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerRelayReference> {
        java.lang.String relayId;

        /**
         * Sets the value of {@link MailManagerRelayReference#getRelayId}
         * @param relayId The RelayId of the MailManagerRelay resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder relayId(java.lang.String relayId) {
            this.relayId = relayId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerRelayReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerRelayReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerRelayReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerRelayReference {
        private final java.lang.String relayId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.relayId = software.amazon.jsii.Kernel.get(this, "relayId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.relayId = java.util.Objects.requireNonNull(builder.relayId, "relayId is required");
        }

        @Override
        public final java.lang.String getRelayId() {
            return this.relayId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("relayId", om.valueToTree(this.getRelayId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerRelayReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerRelayReference.Jsii$Proxy that = (MailManagerRelayReference.Jsii$Proxy) o;

            return this.relayId.equals(that.relayId);
        }

        @Override
        public final int hashCode() {
            int result = this.relayId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerRelayReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerRelay resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerRelayReference mailManagerRelayReference = MailManagerRelayReference.builder()
 *         .relayArn("relayArn")
 *         .relayId("relayId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.210Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerRelayReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerRelayReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerRelayReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the MailManagerRelay resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRelayArn();

    /**
     * The RelayId of the MailManagerRelay resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRelayId();

    /**
     * @return a {@link Builder} of {@link MailManagerRelayReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerRelayReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerRelayReference> {
        java.lang.String relayArn;
        java.lang.String relayId;

        /**
         * Sets the value of {@link MailManagerRelayReference#getRelayArn}
         * @param relayArn The ARN of the MailManagerRelay resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder relayArn(java.lang.String relayArn) {
            this.relayArn = relayArn;
            return this;
        }

        /**
         * Sets the value of {@link MailManagerRelayReference#getRelayId}
         * @param relayId The RelayId of the MailManagerRelay resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder relayId(java.lang.String relayId) {
            this.relayId = relayId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerRelayReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerRelayReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerRelayReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerRelayReference {
        private final java.lang.String relayArn;
        private final java.lang.String relayId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.relayArn = software.amazon.jsii.Kernel.get(this, "relayArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.relayId = software.amazon.jsii.Kernel.get(this, "relayId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.relayArn = java.util.Objects.requireNonNull(builder.relayArn, "relayArn is required");
            this.relayId = java.util.Objects.requireNonNull(builder.relayId, "relayId is required");
        }

        @Override
        public final java.lang.String getRelayArn() {
            return this.relayArn;
        }

        @Override
        public final java.lang.String getRelayId() {
            return this.relayId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("relayArn", om.valueToTree(this.getRelayArn()));
            data.set("relayId", om.valueToTree(this.getRelayId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerRelayReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerRelayReference.Jsii$Proxy that = (MailManagerRelayReference.Jsii$Proxy) o;

            if (!relayArn.equals(that.relayArn)) return false;
            return this.relayId.equals(that.relayId);
        }

        @Override
        public final int hashCode() {
            int result = this.relayArn.hashCode();
            result = 31 * result + (this.relayId.hashCode());
            return result;
        }
    }
}
